@@ -21,11 +21,21 @@ class Http500TestView(TemplateView):
 
 
 class HybridView(View):
-    """View that renders view1 if user is authenticated, otherwise view2."""
-    view1 = None
-    view1_kwargs = None
-    view2 = None
-    view2_kwargs = None
+    """
+    View that renders different views depending on wether the user is authed.
+
+    If the user is authenticated, it will render ``authed_view``, otherwise
+    it will render ``anonymous_view``.
+
+    If you are passing in a function based view you can also define
+    ``authed_view_kwargs`` and ``anonymous_view_kwargs`` which, of course,
+    should be dictionaries.
+
+    """
+    authed_view = None
+    authed_view_kwargs = None
+    anonymous_view = None
+    anonymous_view_kwargs = None
 
     @classmethod
     def as_view(cls, **initkwargs):
@@ -51,10 +61,11 @@ class HybridView(View):
             self.request = request
             self.args = args
             self.kwargs = kwargs
-            self.view1 = initkwargs.get('view1')
-            self.view1_kwargs = initkwargs.get('view1_kwargs')
-            self.view2 = initkwargs.get('view2')
-            self.view2_kwargs = initkwargs.get('view2_kwargs')
+            self.authed_view = initkwargs.get('authed_view')
+            self.authed_view_kwargs = initkwargs.get('authed_view_kwargs')
+            self.anonymous_view = initkwargs.get('anonymous_view')
+            self.anonymous_view_kwargs = initkwargs.get(
+                'anonymous_view_kwargs')
             return self.dispatch(request, *args, **kwargs)
         # take name and docstring from class
         update_wrapper(view, cls, updated=())
@@ -65,11 +76,11 @@ class HybridView(View):
 
     def dispatch(self, request, *args, **kwargs):
         if request.user.is_authenticated():
-            view_kwargs = self.view1_kwargs or {}
-            return self.view1(request, **view_kwargs)
+            view_kwargs = self.authed_view_kwargs or {}
+            return self.authed_view(request, **view_kwargs)
 
-        view_kwargs = self.view2_kwargs or {}
-        return self.view2(request, **view_kwargs)
+        view_kwargs = self.anonymous_view_kwargs or {}
+        return self.anonymous_view(request, **view_kwargs)
 
 
 class RapidPrototypingView(TemplateView):
